@@ -1,10 +1,10 @@
 package Method::Generate::Constructor;
 
 use strictures 1;
-use Sub::Quote qw(quote_sub unquote_sub quotify);
+use Sub::Quote;
 use base qw(Moo::Object);
 use Sub::Defer;
-use Moo::_Utils qw(_getstash);
+use B 'perlstring';
 
 sub register_attribute_specs {
   my ($self, @new_specs) = @_;
@@ -14,29 +14,10 @@ sub register_attribute_specs {
       die "has '+${name}' given but no ${name} attribute already exists"
         unless my $old_spec = $specs->{$name};
       foreach my $key (keys %$old_spec) {
-        if (!exists $new_spec->{$key}) {
-          $new_spec->{$key} = $old_spec->{$key}
-            unless $key eq 'handles';
-        }
-        elsif ($key eq 'moosify') {
-          $new_spec->{$key} = [
-            map { ref $_ eq 'ARRAY' ? @$_ : $_ }
-              ($old_spec->{$key}, $new_spec->{$key})
-          ];
+        $new_spec->{$key} = $old_spec->{$key}
+          unless exists $new_spec->{$key};
         }
       }
-    }
-    if ($new_spec->{required}
-      && !(
-        exists $new_spec->{default}
-        || $new_spec->{builder}
-        || !exists $new_spec->{init_arg}
-        || defined $new_spec->{init_arg}
-      )
-    ) {
-      die "You cannot have a required attribute (${name})"
-        . " without a default, builder, or an init_arg";
-    }
     $new_spec->{index} = scalar keys %$specs
       unless defined $new_spec->{index};
     $specs->{$name} = $new_spec;
@@ -55,21 +36,9 @@ sub accessor_generator {
 sub construction_string {
   my ($self) = @_;
   $self->{construction_string}
-    ||= $self->_build_construction_string;
-}
-
-sub buildall_generator {
-  require Method::Generate::BuildAll;
-  Method::Generate::BuildAll->new;
-}
-
-sub _build_construction_string {
-  my ($self) = @_;
-  my $builder = $self->{construction_builder};
-  $builder ? $self->$builder
-    : 'bless('
-    .$self->accessor_generator->default_construction_string
-    .', $class);'
+    or 'bless('
+       .$self->accessor_generator->default_construction_string
+       .', $class);'
 }
 
 sub install_delayed {
@@ -102,7 +71,8 @@ sub generate_method {
   $body .= '    my $new = '.$self->construction_string.";\n";
   $body .= $self->_assign_new($spec);
   if ($into->can('BUILD')) {
-    $body .= $self->buildall_generator->buildall_body_for(
+    require Method::Generate::BuildAll;
+    $body .= Method::Generate::BuildAll->new->buildall_body_for(
       $into, '$new', '$args'
     );
   }
@@ -120,7 +90,7 @@ sub generate_method {
 sub _handle_subconstructor {
   my ($self, $into, $name) = @_;
   if (my $gen = $self->{subconstructor_handler}) {
-    '    if ($class ne '.quotify($into).') {'."\n".
+    '    if ($class ne '.perlstring($into).') {'."\n".
     $gen.
     '    }'."\n";
   } else {
@@ -154,8 +124,8 @@ sub _generate_args {
         $args = { %{ $_[0] } };
     }
     elsif ( @_ % 2 ) {
-        die "The new() method for $class expects a hash reference or a"
-          . " key/value list. You passed an odd number of arguments\n";
+        die "The new() method for $class expects a hash reference or a key/value list."
+                . " You passed an odd number of arguments\n";
     }
     else {
         $args = {@_};
@@ -175,12 +145,12 @@ sub _assign_new {
     $test{$name} = $attr_spec->{init_arg};
   }
   join '', map {
-    my $arg_key = quotify($test{$_});
+    my $arg_key = perlstring($test{$_});
     my $test = "exists \$args->{$arg_key}";
     my $source = "\$args->{$arg_key}";
     my $attr_spec = $spec->{$_};
     $self->_cap_call($ag->generate_populate_set(
-      '$new', $_, $attr_spec, $source, $test, $test{$_},
+      '$new', $_, $attr_spec, $source, $test
     ));
   } sort keys %test;
 }
@@ -200,17 +170,44 @@ sub _check_required {
     ."    }\n";
 }
 
-use Moo;
-Moo->_constructor_maker_for(__PACKAGE__)->register_attribute_specs(
-  attribute_specs => {
-    is => 'ro',
-    reader => 'all_attribute_specs',
-  },
-  accessor_generator => { is => 'ro' },
-  construction_string => { is => 'lazy' },
-  construction_builder => { is => 'bare' },
-  subconstructor_handler => { is => 'ro' },
-  package => { is => 'bare' },
-);
+sub _check_isa {
+  my ($self, $spec) = @_;
+  my $acc = $self->accessor_generator;
+  my $captures = $self->{captures};
+  my $check = '';
+  foreach my $name (sort keys %$spec) {
+    my ($init, $isa) = @{$spec->{$name}}{qw(init_arg isa)};
+    next unless $init and $isa;
+    my $init_str = perlstring($init);
+    my ($code, $add_captures) = $acc->generate_isa_check(
+      $name, "\$args->{${init_str}}", $isa
+    );
+    @{$captures}{keys %$add_captures} = values %$add_captures;
+    $check .= "    ${code}".(
+      (not($spec->{lazy}) and ($spec->{default} or $spec->{builder})
+        ? ";\n"
+        : "if exists \$args->{${init_str}};\n"
+      )
+    );
+  }
+  return $check;
+}
+
+sub _fire_triggers {
+  my ($self, $spec) = @_;
+  my $acc = $self->accessor_generator;
+  my $captures = $self->{captures};
+  my $fire = '';
+  foreach my $name (sort keys %$spec) {
+    my ($init, $trigger) = @{$spec->{$name}}{qw(init_arg trigger)};
+    next unless $init && $trigger;
+    my ($code, $add_captures) = $acc->generate_trigger(
+      $name, '$new', $acc->generate_simple_get('$new', $name, $spec), $trigger
+    );
+    @{$captures}{keys %$add_captures} = values %$add_captures;
+    $fire .= "    ${code} if exists \$args->{${\perlstring $init}};\n";
+  }
+  return $fire;
+}
 
 1;
