@@ -1,9 +1,11 @@
 package Moo;
 
-use Moo::_strictures;
+use strictures 1;
 use Moo::_Utils;
+use B 'perlstring';
+use Sub::Defer ();
 
-our $VERSION = '1.999_001';
+our $VERSION = '1.000001'; # 1.0.1
 $VERSION = eval $VERSION;
 
 require Moo::sification;
@@ -19,15 +21,9 @@ sub _install_tracked {
 sub import {
   my $target = caller;
   my $class = shift;
-  _set_loaded(caller);
-
-  strict->import;
-  warnings->import;
-
-  if ($INC{'Role/Tiny.pm'} and Role::Tiny->is_role($target)) {
-    die "Cannot import Moo into a role";
-  }
-  $MAKERS{$target} ||= {};
+  strictures->import;
+  return if $MAKERS{$target}; # already exported into this package
+  $MAKERS{$target} = {};
   _install_tracked $target => extends => sub {
     $class->_set_superclasses($target, @_);
     $class->_maybe_reset_handlemoose($target);
@@ -39,24 +35,12 @@ sub import {
     $class->_maybe_reset_handlemoose($target);
   };
   _install_tracked $target => has => sub {
-    my $name_proto = shift;
-    my @name_proto = ref $name_proto eq 'ARRAY' ? @$name_proto : $name_proto;
-    if (@_ % 2 != 0) {
-      require Carp;
-      Carp::croak("Invalid options for " . join(', ', map "'$_'", @name_proto)
-        . " attribute(s): even number of arguments expected, got " . scalar @_)
-    }
-    my %spec = @_;
-    foreach my $name (@name_proto) {
-      # Note that when multiple attributes specified, each attribute
-      # needs a separate \%specs hashref
-      my $spec_ref = @name_proto > 1 ? +{%spec} : \%spec;
-      $class->_constructor_maker_for($target)
-            ->register_attribute_specs($name, $spec_ref);
-      $class->_accessor_maker_for($target)
-            ->generate_method($target, $name, $spec_ref);
-      $class->_maybe_reset_handlemoose($target);
-    }
+    my ($name, %spec) = @_;
+    $class->_constructor_maker_for($target)
+          ->register_attribute_specs($name, \%spec);
+    $class->_accessor_maker_for($target)
+          ->generate_method($target, $name, \%spec);
+    $class->_maybe_reset_handlemoose($target);
     return;
   };
   foreach my $type (qw(before after around)) {
@@ -66,11 +50,6 @@ sub import {
       return;
     };
   }
-  return if $MAKERS{$target}{is_class}; # already exported into this package
-  my $stash = _getstash($target);
-  my @not_methods = map { *$_{CODE}||() } grep !ref($_), values %$stash;
-  @{$MAKERS{$target}{not_methods}={}}{@not_methods} = @not_methods;
-  $MAKERS{$target}{is_class} = 1;
   {
     no strict 'refs';
     @{"${target}::ISA"} = do {
@@ -90,28 +69,24 @@ sub unimport {
 sub _set_superclasses {
   my $class = shift;
   my $target = shift;
-  foreach my $superclass (@_) {
-    _load_module($superclass);
-    if ($INC{'Role/Tiny.pm'} && Role::Tiny->is_role($superclass)) {
+  for (@_) {
+    _load_module($_);
+    if ($INC{"Role/Tiny.pm"} && $Role::Tiny::INFO{$_}) {
       require Carp;
-      Carp::croak("Can't extend role '$superclass'");
+      Carp::croak("Can't extend role '$_'");
     }
   }
   # Can't do *{...} = \@_ or 5.10.0's mro.pm stops seeing @ISA
   @{*{_getglob("${target}::ISA")}{ARRAY}} = @_;
   if (my $old = delete $Moo::MAKERS{$target}{constructor}) {
-    $old->assert_constructor;
     delete _getstash($target)->{new};
     Moo->_constructor_maker_for($target)
        ->register_attribute_specs(%{$old->all_attribute_specs});
   }
-  elsif (!$target->isa('Moo::Object')) {
-    Moo->_constructor_maker_for($target);
-  }
   no warnings 'once'; # piss off. -- mst
   $Moo::HandleMoose::MOUSE{$target} = [
     grep defined, map Mouse::Util::find_meta($_), @_
-  ] if Mouse::Util->can('find_meta');
+  ] if $INC{"Mouse.pm"};
 }
 
 sub _maybe_reset_handlemoose {
@@ -127,8 +102,7 @@ sub _accessor_maker_for {
   $MAKERS{$target}{accessor} ||= do {
     my $maker_class = do {
       if (my $m = do {
-            require Sub::Defer;
-            if (my $defer_target =
+            if (my $defer_target = 
                   (Sub::Defer::defer_info($target->can('new'))||[])->[0]
               ) {
               my ($pkg) = ($defer_target =~ /^(.*)::[^:]+$/);
@@ -148,104 +122,69 @@ sub _accessor_maker_for {
 }
 
 sub _constructor_maker_for {
-  my ($class, $target) = @_;
+  my ($class, $target, $select_super) = @_;
   return unless $MAKERS{$target};
   $MAKERS{$target}{constructor} ||= do {
     require Method::Generate::Constructor;
     require Sub::Defer;
+    my ($moo_constructor, $con);
 
-    my %construct_opts = (
-      package => $target,
-      accessor_generator => $class->_accessor_maker_for($target),
-      subconstructor_handler => (
-        '      if ($Moo::MAKERS{$class}) {'."\n"
-        .'        if ($Moo::MAKERS{$class}{constructor}) {'."\n"
-        .'          return $class->'.$target.'::SUPER::new(@_);'."\n"
-        .'        }'."\n"
-        .'        '.$class.'->_constructor_maker_for($class);'."\n"
-        .'        return $class->new(@_)'.";\n"
-        .'      } elsif ($INC{"Moose.pm"} and my $meta = Class::MOP::get_metaclass_by_name($class)) {'."\n"
-        .'        return $meta->new_object('."\n"
-        .'          $class->can("BUILDARGS") ? $class->BUILDARGS(@_)'."\n"
-        .'                      : $class->Moo::Object::BUILDARGS(@_)'."\n"
-        .'        );'."\n"
-        .'      }'."\n"
-      ),
-    );
-
-    my $con;
-    my @isa = @{mro::get_linear_isa($target)};
-    shift @isa;
-    if (my ($parent_new) = grep { *{_getglob($_.'::new')}{CODE} } @isa) {
-      if ($parent_new eq 'Moo::Object') {
-        # no special constructor needed
+    if ($select_super && $MAKERS{$select_super}) {
+      $moo_constructor = 1;
+      $con = $MAKERS{$select_super}{constructor};
+    } else {
+      my $t_new = $target->can('new');
+      if ($t_new) {
+        if ($t_new == Moo::Object->can('new')) {
+          $moo_constructor = 1;
+        } elsif (my $defer_target = (Sub::Defer::defer_info($t_new)||[])->[0]) {
+          my ($pkg) = ($defer_target =~ /^(.*)::[^:]+$/);
+          if ($MAKERS{$pkg}) {
+            $moo_constructor = 1;
+            $con = $MAKERS{$pkg}{constructor};
+          }
+        }
+      } else {
+        $moo_constructor = 1; # no other constructor, make a Moo one
       }
-      elsif (my $makers = $MAKERS{$parent_new}) {
-        $con = $makers->{constructor};
-        $construct_opts{construction_string} = $con->construction_string
-          if $con;
-      }
-      elsif ($parent_new->can('BUILDALL')) {
-        $construct_opts{construction_builder} = sub {
-          my $inv = $target->can('BUILDARGS') ? '' : 'Moo::Object::';
-          'do {'
-          .'  my $args = $class->'.$inv.'BUILDARGS(@_);'
-          .'  $args->{__no_BUILD__} = 1;'
-          .'  $class->'.$target.'::SUPER::new($args);'
-          .'}'
-        };
-      }
-      else {
-        $construct_opts{construction_builder} = sub {
-          '$class->'.$target.'::SUPER::new('
-            .($target->can('FOREIGNBUILDARGS') ?
-              '$class->FOREIGNBUILDARGS(@_)' : '@_')
-            .')'
-        };
-      }
-    }
+    };
     ($con ? ref($con) : 'Method::Generate::Constructor')
-      ->new(%construct_opts)
+      ->new(
+        package => $target,
+        accessor_generator => $class->_accessor_maker_for($target),
+        construction_string => (
+          $moo_constructor
+            ? ($con ? $con->construction_string : undef)
+            : ('$class->'.$target.'::SUPER::new(@_)')
+        ),
+        subconstructor_handler => (
+          '      if ($Moo::MAKERS{$class}) {'."\n"
+          .'        '.$class.'->_constructor_maker_for($class,'.perlstring($target).');'."\n"
+          .'        return $class->new(@_)'.";\n"
+          .'      } elsif ($INC{"Moose.pm"} and my $meta = Class::MOP::get_metaclass_by_name($class)) {'."\n"
+          .'        return $meta->new_object(@_);'."\n"
+          .'      }'."\n"
+        ),
+      )
       ->install_delayed
       ->register_attribute_specs(%{$con?$con->all_attribute_specs:{}})
   }
 }
 
-sub _concrete_methods_of {
-  my ($me, $role) = @_;
-  my $makers = $MAKERS{$role};
-  # grab role symbol table
-  my $stash = _getstash($role);
-  # reverse so our keys become the values (captured coderefs) in case
-  # they got copied or re-used since
-  my $not_methods = { reverse %{$makers->{not_methods}||{}} };
-  +{
-    # grab all code entries that aren't in the not_methods list
-    map {
-      my $code = *{$stash->{$_}}{CODE};
-      ( ! $code or exists $not_methods->{$code} ) ? () : ($_ => $code)
-    } grep !ref($stash->{$_}), keys %$stash
-  };
-}
-
 1;
-__END__
-
 =pod
 
 =encoding utf-8
 
 =head1 NAME
 
-Moo - Minimalist Object Orientation (with Moose compatibility)
+Moo - Minimalist Object Orientation (with Moose compatiblity)
 
 =head1 SYNOPSIS
 
  package Cat::Food;
 
  use Moo;
- use strictures 2;
- use namespace::clean;
 
  sub feed_lion {
    my $self = shift;
@@ -263,7 +202,7 @@ Moo - Minimalist Object Orientation (with Moose compatibility)
    isa => sub {
      die "Only SWEET-TREATZ supported!" unless $_[0] eq 'SWEET-TREATZ'
    },
- );
+);
 
  has pounds => (
    is  => 'rw',
@@ -286,63 +225,56 @@ And elsewhere:
 
 =head1 DESCRIPTION
 
-C<Moo> is an extremely light-weight Object Orientation system. It allows one to
-concisely define objects and roles with a convenient syntax that avoids the
-details of Perl's object system.  C<Moo> contains a subset of L<Moose> and is
-optimised for rapid startup.
+This module is an extremely light-weight subset of L<Moose> optimised for
+rapid startup and "pay only for what you use".
 
-C<Moo> avoids depending on any XS modules to allow for simple deployments.  The
-name C<Moo> is based on the idea that it provides almost -- but not quite --
-two thirds of L<Moose>.
+It also avoids depending on any XS modules to allow simple deployments.  The
+name C<Moo> is based on the idea that it provides almost -- but not quite -- two
+thirds of L<Moose>.
 
 Unlike L<Mouse> this module does not aim at full compatibility with
-L<Moose>'s surface syntax, preferring instead to provide full interoperability
-via the metaclass inflation capabilities described in L</MOO AND MOOSE>.
+L<Moose>'s surface syntax, preferring instead of provide full interoperability
+via the metaclass inflation capabilites described in L</MOO AND MOOSE>.
 
 For a full list of the minor differences between L<Moose> and L<Moo>'s surface
-syntax, see L</INCOMPATIBILITIES WITH MOOSE>.
+syntax, see L</INCOMPATIBILITIES>.
 
 =head1 WHY MOO EXISTS
 
 If you want a full object system with a rich Metaprotocol, L<Moose> is
 already wonderful.
 
-But if you don't want to use L<Moose>, you may not want "less metaprotocol"
-like L<Mouse> offers, but you probalby want "no metaprotocol", which is what
-Moo provides. C<Moo> is ideal for some situations where deployment or startup
-time precludes using L<Moose> and L<Mouse>:
+However, sometimes you're writing a command line script or a CGI script
+where fast startup is essential, or code designed to be deployed as a single
+file via L<App::FatPacker>, or you're writing a CPAN module and you want it
+to be usable by people with those constraints.
 
-=over 2
+I've tried several times to use L<Mouse> but it's 3x the size of Moo and
+takes longer to load than most of my Moo based CGI scripts take to run.
 
-=item a command line or CGI script where fast startup is essential
+If you don't want L<Moose>, you don't want "less metaprotocol" like L<Mouse>,
+you want "as little as possible" -- which means "no metaprotocol", which is
+what Moo provides.
 
-=item code designed to be deployed as a single file via L<App::FatPacker>
+Better still, if you install and load L<Moose>, we set up metaclasses for your
+L<Moo> classes and L<Moo::Role> roles, so you can use them in L<Moose> code
+without ever noticing that some of your codebase is using L<Moo>.
 
-=item a CPAN module that may be used by others in the above situations
-
-=back
-
-C<Moo> maintains transparent compatibility with L<Moose> so if you install and
-load L<Moose> you can use Moo clases and roles in L<Moose> code without
-modification.
-
-Moo -- Minimal Object Orientation -- aims to make it smooth to upgrade to
-L<Moose> when you need more than the minimal features offered by Moo.
+Hence, Moo exists as its name -- Minimal Object Orientation -- with a pledge
+to make it smooth to upgrade to L<Moose> when you need more than minimal
+features.
 
 =head1 MOO AND MOOSE
 
 If L<Moo> detects L<Moose> being loaded, it will automatically register
 metaclasses for your L<Moo> and L<Moo::Role> packages, so you should be able
-to use them in L<Moose> code without modification.
-
-L<Moo> will also create L<Moose type constraints|Moose::Manual::Types> for
-L<Moo> classes and roles, so that in Moose classes C<< isa => 'MyMooClass' >>
-and C<< isa => 'MyMooRole' >> work the same as for L<Moose> classes and roles.
+to use them in L<Moose> code without anybody ever noticing you aren't using
+L<Moose> everywhere.
 
 Extending a L<Moose> class or consuming a L<Moose::Role> will also work.
 
-Extending a L<Mouse> class or consuming a L<Mouse::Role> will also work. But
-note that we don't provide L<Mouse> metaclasses or metaroles so the other way
+So will extending a L<Mouse> class or consuming a L<Mouse::Role> - but note
+that we don't provide L<Mouse> metaclasses or metaroles so the other way
 around doesn't work. This feature exists for L<Any::Moose> users porting to
 L<Moo>; enabling L<Mouse> users to use L<Moo> classes is not a priority for us.
 
@@ -352,21 +284,19 @@ handle L<Mouse> code, you'll likely need an empty Moo role or class consuming
 or extending the L<Mouse> stuff since it doesn't register true L<Moose>
 metaclasses like L<Moo> does.
 
+If you want types to be upgraded to the L<Moose> types, use
+L<MooX::Types::MooseLike> and install the L<MooseX::Types> library to
+match the L<MooX::Types::MooseLike> library you're using - L<Moo> will
+load the L<MooseX::Types> library and use that type for the newly created
+metaclass.
+
 If you need to disable the metaclass creation, add:
 
   no Moo::sification;
 
 to your code before Moose is loaded, but bear in mind that this switch is
-global and turns the mechanism off entirely so don't put this in library code.
-
-=head1 MOO AND CLASS::XSACCESSOR
-
-If a new enough version of L<Class::XSAccessor> is available, it
-will be used to generate simple accessors, readers, and writers for
-better performance.  Simple accessors are those without lazy defaults,
-type checks/coercions, or triggers.  Readers and writers generated
-by L<Class::XSAccessor> will behave slightly differently: they will
-reject attempts to call them with the incorrect number of parameters.
+currently global and turns the mechanism off entirely so don't put this
+in library code.
 
 =head1 MOO VERSUS ANY::MOOSE
 
@@ -418,13 +348,6 @@ passed to the constructor.
 
 This method should always return a hash reference of named options.
 
-=head2 FOREIGNBUILDARGS
-
-If you are inheriting from a non-Moo class, the arguments passed to the parent
-class constructor can be manipulated by defining a C<FOREIGNBUILDARGS> method.
-It will receive the same arguments as C<BUILDARGS>, and should return a list
-of arguments to pass to the parent class constructor.
-
 =head2 BUILD
 
 Define a C<BUILD> method on your class and the constructor will automatically
@@ -457,10 +380,8 @@ Returns true if the object composes in the passed role.
 
  extends 'Parent::Class';
 
-Declares a base class. Multiple superclasses can be passed for multiple
-inheritance but please consider using L<roles|Moo::Role> instead.  The class
-will be loaded but no errors will be triggered if the class can't be found and
-there are already subs in the class.
+Declares base class. Multiple superclasses can be passed for multiple
+inheritance (but please use roles instead).
 
 Calling extends more than once will REPLACE your superclasses, not add to
 them like 'use base' would.
@@ -474,9 +395,7 @@ or
  with 'Some::Role1', 'Some::Role2';
 
 Composes one or more L<Moo::Role> (or L<Role::Tiny>) roles into the current
-class.  An error will be raised if these roles cannot be composed because they
-have conflicting method definitions.  The roles will be loaded using the same
-mechansim as C<extends> uses.
+class.  An error will be raised if these roles have conflicting methods.
 
 =head2 has
 
@@ -486,64 +405,41 @@ mechansim as C<extends> uses.
 
 Declares an attribute for the class.
 
- package Foo;
- use Moo;
- has 'attr' => (
-   is => 'ro'
- );
-
- package Bar;
- use Moo;
- extends 'Foo';
- has '+attr' => (
-   default => sub { "blah" },
- );
-
-Using the C<+> notation, it's possible to override an attribute.
-
 The options for C<has> are as follows:
 
 =over 2
 
-=item * C<is>
+=item * is
 
 B<required>, may be C<ro>, C<lazy>, C<rwp> or C<rw>.
 
-C<ro> stands for "read-only" and generates an accessor that dies if you attempt
-to write to it - i.e.  a getter only - by defaulting C<reader> to the name of
-the attribute.
+C<ro> generates an accessor that dies if you attempt to write to it - i.e.
+a getter only - by defaulting C<reader> to the name of the attribute.
 
 C<lazy> generates a reader like C<ro>, but also sets C<lazy> to 1 and
 C<builder> to C<_build_${attribute_name}> to allow on-demand generated
 attributes.  This feature was my attempt to fix my incompetence when
 originally designing C<lazy_build>, and is also implemented by
-L<MooseX::AttributeShortcuts>. There is, however, nothing to stop you
-using C<lazy> and C<builder> yourself with C<rwp> or C<rw> - it's just that
-this isn't generally a good idea so we don't provide a shortcut for it.
+L<MooseX::AttributeShortcuts>.
 
-C<rwp> stands for "read-write protected" and generates a reader like C<ro>, but
-also sets C<writer> to C<_set_${attribute_name}> for attributes that are
-designed to be written from inside of the class, but read-only from outside.
+C<rwp> generates a reader like C<ro>, but also sets C<writer> to
+C<_set_${attribute_name}> for attributes that are designed to be written
+from inside of the class, but read-only from outside.
 This feature comes from L<MooseX::AttributeShortcuts>.
 
-C<rw> stands for "read-write" and generates a normal getter/setter by
-defaulting the C<accessor> to the name of the attribute specified.
+C<rw> generates a normal getter/setter by defaulting C<accessor> to the
+name of the attribute.
 
-=item * C<isa>
+=item * isa
 
-Takes a coderef which is used to validate the attribute.  Unlike L<Moose>, Moo
+Takes a coderef which is meant to validate the attribute.  Unlike L<Moose>, Moo
 does not include a basic type system, so instead of doing C<< isa => 'Num' >>,
 one should do
 
- use Scalar::Util qw(looks_like_number);
- ...
  isa => sub {
    die "$_[0] is not a number!" unless looks_like_number $_[0]
  },
 
-Note that the return value for C<isa> is discarded. Only if the sub dies does
-type validation fail.
-
 L<Sub::Quote aware|/SUB QUOTE AWARE>
 
 Since L<Moo> does B<not> run the C<isa> check before C<coerce> if a coercion
@@ -552,8 +448,8 @@ and can, if desired, be omitted on non-debug builds (although if this results
 in an uncaught bug causing your program to break, the L<Moo> authors guarantee
 nothing except that you get to keep both halves).
 
-If you want L<Moose> compatible or L<MooseX::Types> style named types, look at
-L<Type::Tiny>.
+If you want L<MooseX::Types> style named types, look at
+L<MooX::Types::MooseLike>.
 
 To cause your C<isa> entries to be automatically mapped to named
 L<Moose::Meta::TypeConstraint> objects (rather than the default behaviour
@@ -568,32 +464,29 @@ Note that this example is purely illustrative; anything that returns a
 L<Moose::Meta::TypeConstraint> object or something similar enough to it to
 make L<Moose> happy is fine.
 
-=item * C<coerce>
+=item * coerce
 
 Takes a coderef which is meant to coerce the attribute.  The basic idea is to
 do something like the following:
 
  coerce => sub {
-   $_[0] % 2 ? $_[0] : $_[0] + 1
+   $_[0] + 1 unless $_[0] % 2
  },
 
-Note that L<Moo> will always execute your coercion: this is to permit
+Note that L<Moo> will always fire your coercion: this is to permit
 C<isa> entries to be used purely for bug trapping, whereas coercions are
 always structural to your code. We do, however, apply any supplied C<isa>
 check after the coercion has run to ensure that it returned a valid value.
 
 L<Sub::Quote aware|/SUB QUOTE AWARE>
 
-If the C<isa> option is a blessed object providing a C<coerce> or
-C<coercion> method, then the C<coerce> option may be set to just C<1>.
-
-=item * C<handles>
+=item * handles
 
 Takes a string
 
   handles => 'RobotRole'
 
-Where C<RobotRole> is a L<role|Moo::Role> that defines an interface which
+Where C<RobotRole> is a role (L<Moo::Role>) that defines an interface which
 becomes the list of methods to handle.
 
 Takes a list of methods
@@ -606,11 +499,11 @@ Takes a hashref
    un => 'one',
  }
 
-=item * C<trigger>
+=item * trigger
 
 Takes a coderef which will get called any time the attribute is set. This
-includes the constructor, but not default or built values. The coderef will be
-invoked against the object with the new value as an argument.
+includes the constructor. Coderef will be invoked against the object with the
+new value as an argument.
 
 If you set this to just C<1>, it generates a trigger which calls the
 C<_trigger_${attr_name}> method on C<$self>. This feature comes from
@@ -623,14 +516,10 @@ L<Sub::Quote aware|/SUB QUOTE AWARE>
 
 =item * C<default>
 
-Takes a coderef which will get called with $self as its only argument to
-populate an attribute if no value for that attribute was supplied to the
-constructor. Alternatively, if the attribute is lazy, C<default> executes when
-the attribute is first retrieved if no value has yet been provided.
-
-If a simple scalar is provided, it will be inlined as a string. Any non-code
-reference (hash, array) will result in an error - for that case instead use
-a code reference that returns the desired value.
+Takes a coderef which will get called with $self as its only argument
+to populate an attribute if no value is supplied to the constructor - or
+if the attribute is lazy, when the attribute is first retrieved if no
+value has yet been provided.
 
 Note that if your default is fired during new() there is no guarantee that
 other attributes have been populated yet so you should not rely on their
@@ -644,7 +533,7 @@ Takes a method name which will return true if an attribute has a value.
 
 If you set this to just C<1>, the predicate is automatically named
 C<has_${attr_name}> if your attribute's name does not start with an
-underscore, or C<_has_${attr_name_without_the_underscore}> if it does.
+underscore, or <_has_${attr_name_without_the_underscore}> if it does.
 This feature comes from L<MooseX::AttributeShortcuts>.
 
 =item * C<builder>
@@ -658,14 +547,8 @@ Moo will call
 
   $self->$builder;
 
-The following features come from L<MooseX::AttributeShortcuts>:
-
-If you set this to just C<1>, the builder is automatically named
-C<_build_${attr_name}>.
-
-If you set this to a coderef or code-convertible object, that variable will be
-installed under C<$class::_build_${attr_name}> and the builder set to the same
-name.
+If you set this to just C<1>, the predicate is automatically named
+C<_build_${attr_name}>.  This feature comes from L<MooseX::AttributeShortcuts>.
 
 =item * C<clearer>
 
@@ -673,12 +556,9 @@ Takes a method name which will clear the attribute.
 
 If you set this to just C<1>, the clearer is automatically named
 C<clear_${attr_name}> if your attribute's name does not start with an
-underscore, or C<_clear_${attr_name_without_the_underscore}> if it does.
+underscore, or <_clear_${attr_name_without_the_underscore}> if it does.
 This feature comes from L<MooseX::AttributeShortcuts>.
 
-B<NOTE:> If the attribute is C<lazy>, it will be regenerated from C<default> or
-C<builder> the next time it is accessed. If it is not lazy, it will be C<undef>.
-
 =item * C<lazy>
 
 B<Boolean>.  Set this if you want values for the attribute to be grabbed
@@ -687,12 +567,13 @@ another attribute to be set.
 
 =item * C<required>
 
-B<Boolean>.  Set this if the attribute must be passed on object instantiation.
+B<Boolean>.  Set this if the attribute must be passed on instantiation.
 
 =item * C<reader>
 
-The name of the method that returns the value of the attribute.  If you like
-Java style methods, you might set this to C<get_foo>
+The value of this attribute will be the name of the method to get the value of
+the attribute.  If you like Java style methods, you might set this to
+C<get_foo>
 
 =item * C<writer>
 
@@ -703,8 +584,8 @@ C<set_foo>.
 =item * C<weak_ref>
 
 B<Boolean>.  Set this if you want the reference that the attribute contains to
-be weakened. Use this when circular references, which cause memory leaks, are
-possible.
+be weakened; use this when circular references are possible, which will cause
+leaks.
 
 =item * C<init_arg>
 
@@ -713,34 +594,27 @@ common use of this is to make an underscored attribute have a non-underscored
 initialization name. C<undef> means that passing the value in on instantiation
 is ignored.
 
-=item * C<moosify>
-
-Takes either a coderef or array of coderefs which is meant to transform the
-given attributes specifications if necessary when upgrading to a Moose role or
-class. You shouldn't need this by default, but is provided as a means of
-possible extensibility.
-
 =back
 
 =head2 before
 
  before foo => sub { ... };
 
-See L<< Class::Method::Modifiers/before method(s) => sub { ... }; >> for full
+See L<< Class::Method::Modifiers/before method(s) => sub { ... } >> for full
 documentation.
 
 =head2 around
 
  around foo => sub { ... };
 
-See L<< Class::Method::Modifiers/around method(s) => sub { ... }; >> for full
+See L<< Class::Method::Modifiers/around method(s) => sub { ... } >> for full
 documentation.
 
 =head2 after
 
  after foo => sub { ... };
 
-See L<< Class::Method::Modifiers/after method(s) => sub { ... }; >> for full
+See L<< Class::Method::Modifiers/after method(s) => sub { ... } >> for full
 documentation.
 
 =head1 SUB QUOTE AWARE
@@ -751,14 +625,11 @@ aware can take advantage of this.
 
 To do this, you can write
 
+  use Moo;
   use Sub::Quote;
 
-  use Moo;
-  use namespace::clean;
-
   has foo => (
-    is => 'ro',
-    isa => quote_sub(q{ die "Not <3" unless $_[0] < 3 })
+    is => quote_sub(q{ die "Not <3" unless $_[0] < 3 })
   );
 
 which will be inlined as
@@ -771,8 +642,7 @@ which will be inlined as
 or to avoid localizing @_,
 
   has foo => (
-    is => 'ro',
-    isa => quote_sub(q{ my ($val) = @_; die "Not <3" unless $val < 3 })
+    is => quote_sub(q{ my ($val) = @_; die "Not <3" unless $val < 3 })
   );
 
 which will be inlined as
@@ -785,64 +655,26 @@ which will be inlined as
 See L<Sub::Quote> for more information, including how to pass lexical
 captures that will also be compiled into the subroutine.
 
-=head1 CLEANING UP IMPORTS
-
-L<Moo> will not clean up imported subroutines for you; you will have
-to do that manually. The recommended way to do this is to declare your
-imports first, then C<use Moo>, then C<use namespace::clean>.
-Anything imported before L<namespace::clean> will be scrubbed.
-Anything imported or declared after will be still be available.
-
- package Record;
-
- use Digest::MD5 qw(md5_hex);
-
- use Moo;
- use namespace::clean;
-
- has name => (is => 'ro', required => 1);
- has id => (is => 'lazy');
- sub _build_id {
-   my ($self) = @_;
-   return md5_hex($self->name);
- }
-
- 1;
-
-If you were to import C<md5_hex> after L<namespace::clean> you would
-be able to call C<< ->md5_hex() >> on your C<Record> instances (and it
-probably wouldn't do what you expect!).
-
-L<Moo::Role>s behave slightly differently.  Since their methods are
-composed into the consuming class, they can do a little more for you
-automatically.  As long as you declare your imports before calling
-C<use Moo::Role>, those imports and the ones L<Moo::Role> itself
-provides will not be composed into consuming classes so there's usually
-no need to use L<namespace::clean>.
-
-B<On L<namespace::autoclean>:> Older versions of L<namespace::autoclean> would
-inflate Moo classes to full L<Moose> classes, losing the benefits of Moo.  If
-you want to use L<namespace::autoclean> with a Moo class, make sure you are
-using version 0.16 or newer.
-
 =head1 INCOMPATIBILITIES WITH MOOSE
 
 There is no built-in type system.  C<isa> is verified with a coderef; if you
-need complex types, L<Type::Tiny> can provide types, type libraries, and
-will work seamlessly with both L<Moo> and L<Moose>.  L<Type::Tiny> can be
-considered the successor to L<MooseX::Types> and provides a similar API, so
-that you can write
+need complex types, just make a library of coderefs, or better yet, functions
+that return quoted subs. L<MooX::Types::MooseLike> provides a similar API
+to L<MooseX::Types::Moose> so that you can write
 
-  use Types::Standard;
   has days_to_live => (is => 'ro', isa => Int);
 
+and have it work with both; it is hoped that providing only subrefs as an
+API will encourage the use of other type systems as well, since it's
+probably the weakest part of Moose design-wise.
+
 C<initializer> is not supported in core since the author considers it to be a
-bad idea and Moose best practices recommend avoiding it. Meanwhile C<trigger> or
+bad idea but may be supported by an extension in future. Meanwhile C<trigger> or
 C<coerce> are more likely to be able to fulfill your needs.
 
-There is no meta object.  If you need this level of complexity you need
-L<Moose> - Moo is small because it explicitly does not provide a metaprotocol.
-However, if you load L<Moose>, then
+There is no meta object.  If you need this level of complexity you wanted
+L<Moose> - Moo succeeds at being small because it explicitly does not
+provide a metaprotocol. However, if you load L<Moose>, then
 
   Class::MOP::class_of($moo_class_or_role)
 
@@ -868,16 +700,13 @@ The C<dump> method is not provided by default. The author suggests loading
 L<Devel::Dwarn> into C<main::> (via C<perl -MDevel::Dwarn ...> for example) and
 using C<$obj-E<gt>$::Dwarn()> instead.
 
-L</default> only supports coderefs and plain scalars, because passing a hash
-or array reference as a default is almost always incorrect since the value is
-then shared between all objects using that default.
+L</default> only supports coderefs, because doing otherwise is usually a
+mistake anyway.
 
 C<lazy_build> is not supported; you are instead encouraged to use the
-C<< is => 'lazy' >> option supported by L<Moo> and
-L<MooseX::AttributeShortcuts>.
+C<< is => 'lazy' >> option supported by L<Moo> and L<MooseX::AttributeShortcuts>.
 
-C<auto_deref> is not supported since the author considers it a bad idea and
-it has been considered best practice to avoid it for some time.
+C<auto_deref> is not supported since the author considers it a bad idea.
 
 C<documentation> will show up in a L<Moose> metaclass created from your class
 but is otherwise ignored. Then again, L<Moose> ignores it as well, so this
@@ -887,14 +716,11 @@ Since C<coerce> does not require C<isa> to be defined but L<Moose> does
 require it, the metaclass inflation for coerce alone is a trifle insane
 and if you attempt to subtype the result will almost certainly break.
 
-C<BUILDARGS> is not triggered if your class does not have any attributes.
-Without attributes, C<BUILDARGS> return value would be ignored, so we just
-skip calling the method instead.
+Handling of warnings: when you C<use Moo> we enable FATAL warnings.  The nearest
+similar invocation for L<Moose> would be:
 
-Handling of warnings: when you C<use Moo> we enable strict and warnings, in a
-similar way to Moose. The authors recommend the use of C<strictures>, which
-enables FATAL warnings, and several extra pragmas when used in development:
-L<indirect>, L<multidimensional>, and L<bareword::filehandles>.
+  use Moose;
+  use warnings FATAL => "all";
 
 Additionally, L<Moo> supports a set of attribute option shortcuts intended to
 reduce common boilerplate.  The set of shortcuts is the same as in the L<Moose>
@@ -902,7 +728,6 @@ module L<MooseX::AttributeShortcuts> as of its version 0.009+.  So if you:
 
     package MyClass;
     use Moo;
-    use strictures 2;
 
 The nearest L<Moose> invocation would be:
 
@@ -927,29 +752,14 @@ Finally, Moose requires you to call
 
 at the end of your class to get an inlined (i.e. not horribly slow)
 constructor. Moo does it automatically the first time ->new is called
-on your class. (C<make_immutable> is a no-op in Moo to ease migration.)
-
-An extension L<MooX::late> exists to ease translating Moose packages
-to Moo by providing a more Moose-like interface.
+on your class.
 
 =head1 SUPPORT
 
 Users' IRC: #moose on irc.perl.org
 
-=for :html
-L<(click for instant chatroom login)|http://chat.mibbit.com/#moose@irc.perl.org>
-
 Development and contribution IRC: #web-simple on irc.perl.org
 
-=for :html
-L<(click for instant chatroom login)|http://chat.mibbit.com/#web-simple@irc.perl.org>
-
-Bugtracker: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Moo>
-
-Git repository: L<git://github.com/moose/Moo.git>
-
-Git browser: L<https://github.com/moose/Moo>
-
 =head1 AUTHOR
 
 mst - Matt S. Trout (cpan:MSTROUT) <mst@shadowcat.co.uk>
@@ -978,24 +788,14 @@ Mithaldu - Christian Walde (cpan:MITHALDU) <walde.christian@googlemail.com>
 
 ilmari - Dagfinn Ilmari Mannsåker (cpan:ILMARI) <ilmari@ilmari.org>
 
-tobyink - Toby Inkster (cpan:TOBYINK) <tobyink@cpan.org>
-
-haarg - Graham Knop (cpan:HAARG) <haarg@cpan.org>
-
-mattp - Matt Phillips (cpan:MATTP) <mattp@cpan.org>
-
-bluefeet - Aran Deltac (cpan:BLUEFEET) <bluefeet@gmail.com>
-
-bubaflub - Bob Kuo (cpan:BUBAFLUB) <bubaflub@cpan.org>
-
 =head1 COPYRIGHT
 
-Copyright (c) 2010-2015 the Moo L</AUTHOR> and L</CONTRIBUTORS>
+Copyright (c) 2010-2011 the Moo L</AUTHOR> and L</CONTRIBUTORS>
 as listed above.
 
 =head1 LICENSE
 
 This library is free software and may be distributed under the same terms
-as perl itself. See L<http://dev.perl.org/licenses/>.
+as perl itself.
 
 =cut
